@@ -18,8 +18,9 @@ from uiautomatorplug.android import device, ExpectException
 
 
 log = logging.getLogger(__name__)
-
 '''global log instance'''
+LOCATION_NOT_FOUND_EXCEPTION = '%s not found.'
+'''error msg if adb not found'''
 TAG='%s%s%s' % ('-' * 18, 'file output save Plugin', '-' * 18)
 '''global log output tag'''
 TIME_STAMP_FORMAT = '%Y-%m-%d %H:%M:%S'
